@@ -1,6 +1,6 @@
 #
 # ovirt-hosted-engine-setup -- ovirt hosted engine setup
-# Copyright (C) 2013-2014 Red Hat, Inc.
+# Copyright (C) 2013-2015 Red Hat, Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -25,17 +25,18 @@ import gettext
 
 
 from otopi import constants as otopicons
-from otopi import util
-from otopi import plugin
-from otopi import transaction
 from otopi import filetransaction
+from otopi import plugin
+from otopi import util
+from otopi import transaction
 
 
 from ovirt_hosted_engine_setup import constants as ohostedcons
 from ovirt_hosted_engine_setup import util as ohostedutil
 
 
-_ = lambda m: gettext.dgettext(message=m, domain='ovirt-hosted-engine-setup')
+def _(m):
+    return gettext.dgettext(message=m, domain='ovirt-hosted-engine-setup')
 
 
 @util.export
@@ -50,11 +51,11 @@ class Plugin(plugin.PluginBase):
         after=(
             ohostedcons.Stages.VM_IMAGE_AVAILABLE,
             ohostedcons.Stages.BRIDGE_AVAILABLE,
+            ohostedcons.Stages.CONF_VOLUME_AVAILABLE,
         ),
         name=ohostedcons.Stages.SAVE_CONFIG,
     )
     def _misc(self):
-        # TODO: what's an VM_DISK_ID and how can it change to another value?
         self.logger.info(_('Updating hosted-engine configuration'))
         subst = {
             '@FQDN@': self.environment[
@@ -63,6 +64,9 @@ class Plugin(plugin.PluginBase):
             '@VM_DISK_ID@': self.environment[
                 ohostedcons.StorageEnv.IMG_UUID
             ],
+            '@VM_DISK_VOL_ID@': self.environment[
+                ohostedcons.StorageEnv.VOL_UUID
+            ],
             '@SHARED_STORAGE@': self.environment[
                 ohostedcons.StorageEnv.STORAGE_DOMAIN_CONNECTION
             ],
@@ -105,6 +109,12 @@ class Plugin(plugin.PluginBase):
             '@LOCKSPACE_IMAGE_UUID@': self.environment[
                 ohostedcons.StorageEnv.LOCKSPACE_IMAGE_UUID
             ],
+            '@CONF_VOLUME_UUID@': self.environment[
+                ohostedcons.StorageEnv.CONF_VOL_UUID
+            ],
+            '@CONF_IMAGE_UUID@': self.environment[
+                ohostedcons.StorageEnv.CONF_IMG_UUID
+            ],
             '@IQN@': '',
             '@PORTAL@': '',
             '@USER@': '',
@@ -139,6 +149,9 @@ class Plugin(plugin.PluginBase):
             template=ohostedcons.FileLocations.OVIRT_HOSTED_ENGINE_TEMPLATE,
             subst=subst
         )
+        self.environment[
+            ohostedcons.StorageEnv.HECONF_CONTENT
+        ] = content
         with transaction.Transaction() as localtransaction:
             localtransaction.append(
                 filetransaction.FileTransaction(
