@@ -1,6 +1,6 @@
 #
 # ovirt-hosted-engine-setup -- ovirt hosted engine setup
-# Copyright (C) 2013-2014 Red Hat, Inc.
+# Copyright (C) 2013-2015 Red Hat, Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -25,16 +25,17 @@ import gettext
 
 
 from otopi import constants as otopicons
-from otopi import util
 from otopi import context as otopicontext
 from otopi import plugin
+from otopi import util
 
 
 from ovirt_hosted_engine_setup import constants as ohostedcons
 from ovirt_hosted_engine_setup import util as ohostedutil
 
 
-_ = lambda m: gettext.dgettext(message=m, domain='ovirt-hosted-engine-setup')
+def _(m):
+    return gettext.dgettext(message=m, domain='ovirt-hosted-engine-setup')
 
 
 @util.export
@@ -69,6 +70,7 @@ class Plugin(plugin.PluginBase):
             ohostedcons.CoreEnv.DEPLOY_PROCEED,
             None
         )
+        self.environment[ohostedcons.CoreEnv.NODE_SETUP] = False
 
     @plugin.event(
         stage=plugin.Stages.STAGE_SETUP,
@@ -102,7 +104,6 @@ class Plugin(plugin.PluginBase):
             ohostedcons.CoreEnv.REQUIREMENTS_CHECK_ENABLED,
             True
         )
-        self.environment[ohostedcons.CoreEnv.NODE_SETUP] = False
         try:
             # avoid: pyflakes 'Config' imported but unused error
             import ovirt.node.utils.fs
