@@ -1,6 +1,6 @@
 #
 # ovirt-hosted-engine-setup -- ovirt hosted engine setup
-# Copyright (C) 2013-2014 Red Hat, Inc.
+# Copyright (C) 2013-2015 Red Hat, Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -27,15 +27,16 @@ import gettext
 import os
 
 
-from otopi import util
 from otopi import plugin
+from otopi import util
 
 
 from ovirt_hosted_engine_setup import constants as ohostedcons
 from ovirt_hosted_engine_setup import tasks
 
 
-_ = lambda m: gettext.dgettext(message=m, domain='ovirt-hosted-engine-setup')
+def _(m):
+    return gettext.dgettext(message=m, domain='ovirt-hosted-engine-setup')
 
 
 @util.export
@@ -85,35 +86,47 @@ class Plugin(plugin.PluginBase):
     @plugin.event(
         stage=plugin.Stages.STAGE_CLOSEUP,
         after=(
-            ohostedcons.Stages.HOST_ADDED,
+            ohostedcons.Stages.VDSCLI_RECONNECTED,
+            ohostedcons.Stages.CONF_IMAGE_AVAILABLE,
         ),
         name=ohostedcons.Stages.HA_START,
     )
     def _closeup(self):
         # shutdown the vm if this is first host.
         if not self.environment[ohostedcons.CoreEnv.IS_ADDITIONAL_HOST]:
-            self.dialog.note(
-                _(
-                    'Please shutdown the VM allowing the system to launch it '
-                    'as a monitored service.\n'
-                    'The system will wait until the VM is down.'
+
+            if self.environment[
+                ohostedcons.VMEnv.AUTOMATE_VM_SHUTDOWN
+            ]:
+                self.logger.info(_('Shutting down the engine VM'))
+                cli = self.environment[ohostedcons.VDSMEnv.VDS_CLI]
+                res = cli.shutdown(self.environment[ohostedcons.VMEnv.VM_UUID])
+                self.logger.debug(res)
+            else:
+                self.dialog.note(
+                    _(
+                        'Please shutdown the VM allowing the system '
+                        'to launch it as a monitored service.\n'
+                        'The system will wait until the VM is down.'
+                    )
                 )
-            )
             waiter = tasks.VMDownWaiter(self.environment)
             if not waiter.wait():
                 # The VM is down but not destroyed
-                vdscommand = [self.command.get('vdsClient')]
-                if self.environment[ohostedcons.VDSMEnv.USE_SSL]:
-                    vdscommand.append('-s')
-                vdscommand += [
-                    'localhost',
-                    'destroy',
-                    self.environment[ohostedcons.VMEnv.VM_UUID],
-                ]
-                self.execute(
-                    vdscommand,
-                    raiseOnError=True
+                status = self.environment[
+                    ohostedcons.VDSMEnv.VDS_CLI
+                ].destroy(
+                    self.environment[ohostedcons.VMEnv.VM_UUID]
                 )
+                self.logger.debug(status)
+                if status['status']['code'] != 0:
+                    self.logger.error(
+                        _(
+                            'Cannot destroy the Hosted Engine VM: ' +
+                            status['status']['message']
+                        )
+                    )
+                    raise RuntimeError(status['status']['message'])
         self.logger.info(_('Enabling and starting HA services'))
         for service in (
             ohostedcons.Const.HA_AGENT_SERVICE,
@@ -128,4 +141,5 @@ class Plugin(plugin.PluginBase):
                 state=True,
             )
 
+
 # vim: expandtab tabstop=4 shiftwidth=4
